@@ -21,14 +21,18 @@ from .gaal_base import create_discriminator
 from .gaal_base import create_generator
 
 # if tensorflow 2, import from tf directly
-if _get_tensorflow_version() == 1:
+if _get_tensorflow_version() < 200:
     from keras.layers import Input
     from keras.models import Model
     from keras.optimizers import SGD
-else:
+elif 200 <= _get_tensorflow_version() <= 209:
     from tensorflow.keras.layers import Input
     from tensorflow.keras.models import Model
     from tensorflow.keras.optimizers import SGD
+else:
+    from tensorflow.keras.layers import Input
+    from tensorflow.keras.models import Model
+    from tensorflow.keras.optimizers.legacy import SGD
 
 
 class MO_GAAL(BaseDetector):
@@ -62,8 +66,6 @@ class MO_GAAL(BaseDetector):
     lr_g : float, optional (default=0.0001)
         The learn rate of the generator.
 
-    decay : float, optional (default=1e-6)
-        The decay parameter for SGD.
 
     momentum : float, optional (default=0.9)
         The momentum parameter for SGD.
@@ -87,14 +89,12 @@ class MO_GAAL(BaseDetector):
         ``threshold_`` on ``decision_scores_``.
     """
 
-    def __init__(self, k=10, stop_epochs=20, lr_d=0.01, lr_g=0.0001,
-                 decay=1e-6, momentum=0.9, contamination=0.1):
+    def __init__(self, k=10, stop_epochs=20, lr_d=0.01, lr_g=0.0001, momentum=0.9, contamination=0.1):
         super(MO_GAAL, self).__init__(contamination=contamination)
         self.k = k
         self.stop_epochs = stop_epochs
         self.lr_d = lr_d
         self.lr_g = lr_g
-        self.decay = decay
         self.momentum = momentum
 
     def fit(self, X, y=None):
@@ -125,8 +125,7 @@ class MO_GAAL(BaseDetector):
         # Create discriminator
         self.discriminator = create_discriminator(latent_size, data_size)
         self.discriminator.compile(
-            optimizer=SGD(lr=self.lr_d, decay=self.decay,
-                          momentum=self.momentum), loss='binary_crossentropy')
+            optimizer=SGD(lr=self.lr_d, momentum=self.momentum), loss='binary_crossentropy')
 
         # Create k combine models
         for i in range(self.k):
@@ -139,7 +138,6 @@ class MO_GAAL(BaseDetector):
                                                     names['fake' + str(i)])
             names['combine_model' + str(i)].compile(
                 optimizer=SGD(lr=self.lr_g,
-                              decay=self.decay,
                               momentum=self.momentum),
                 loss='binary_crossentropy')
 
